@@ -2,12 +2,11 @@ import asyncio
 import json
 from asyncio import Future
 from pathlib import Path
-from typing import List, Type, TypeVar
+from typing import List, Type, TypeVar, Generic
 
 from pydantic import BaseModel as PdModel
 from pyee import AsyncIOEventEmitter
 
-from web_foundation.app.infrastructure.provide.initiator import Initiator
 from web_foundation.app.service.service import Service
 from web_foundation.kernel import NamedContext
 from web_foundation.kernel.isolates.isolate import Isolate
@@ -15,30 +14,28 @@ from web_foundation.kernel.isolates.isolate import Isolate
 AppConfig = TypeVar("AppConfig", bound=PdModel)
 
 
-class App:
+class App(Generic[AppConfig]):
     emitter: AsyncIOEventEmitter
     config: AppConfig
     name: str
     isolates: List[Isolate]
     services: List[Service]
-    initiators: List[Initiator]
     ctx: NamedContext
     debug: bool
 
-    def __init__(self, name: str, debug: bool = False, initiators: List[Type[Initiator]] = None):
+    def __init__(self, name: str, debug: bool = False):
         self.debug = debug
         self.emitter = AsyncIOEventEmitter()
         self.name = name
         self.ctx = NamedContext()
         self.services = []
         self.isolates = []
-        self.initiators = [] if not initiators else initiators
 
-    def load_config(self, conf_path: Path, config_model: Type[AppConfig]) -> AppConfig:
+    def load_config(self, conf_path: Path, config_model: Type[AppConfig]) -> None:
         """
         Load app config to user in
         :param conf_path:
-        :param config_model: BaseModel to cast json file to pydantc
+        :param config_model: BaseModel to cast json file to pydantic
         :return: None
         """
         with open(conf_path, "r") as _json_file:
@@ -49,7 +46,6 @@ class App:
     def add_isolate(self, isolate: Isolate):
         """
         Set isolate to app and set isolate debug and name
-        :param isolate_name: name was apply to isolate
         :param isolate: isolate to apply
         :return: None
         """
