@@ -105,7 +105,7 @@ class AccessService(Service):
         match inc.request.method:
             case HTTPMethod.GET.value:
                 kwargs = inc.r_kwargs
-                entity_id = kwargs.get("entity_id")
+                entity_id = kwargs.pop("entity_id")
                 if entity_id is None:
                     limit = inc.request.args.get("limit")
                     offset = inc.request.args.get("offset")
@@ -147,13 +147,13 @@ class AccessService(Service):
 
             case HTTPMethod.PATCH.value:
                 assert inc.dto
-                entity_id = inc.r_kwargs.get("entity_id")
+                entity_id = inc.r_kwargs.pop("entity_id")
                 assert entity_id
                 retrieved = await access_middleware.update(model, entity_id, prot, inc.dto, **inc.r_kwargs)
                 return json(await retrieved.values_dict())
 
             case HTTPMethod.DELETE.value:
-                entity_id = inc.r_kwargs.get("entity_id")
+                entity_id = inc.r_kwargs.pop("entity_id")
                 assert entity_id
                 retrieved = await access_middleware.delete(model, entity_id, prot, **inc.r_kwargs)
                 return json(await retrieved.values_dict())
