@@ -1,13 +1,14 @@
 from dataclasses import dataclass
+from typing import TypeVar
 
 import loguru
-from aioprocessing import AioEvent, AioLock, AioQueue
+from aioprocessing import AioEvent, AioLock, AioQueue  # type: ignore
 
 
 class IMessage:
     last_idx = 0
     index: int
-    sender: int
+    sender: str
     destination: str
 
     def __init__(self, destination: str, idx: int = None):
@@ -22,16 +23,19 @@ class IMessage:
         return f"IMessage(id={self.index}, dest={self.destination}, sender={self.sender})"
 
 
+GenericIMessage = TypeVar("GenericIMessage", bound=IMessage, contravariant=True)
+
+
 @dataclass
 class IsolatePipes:
     queue: AioQueue
     event: AioEvent
     lock: AioLock
 
-    async def write(self, msg: IMessage):
+    async def write(self, msg: GenericIMessage):
         await self.queue.coro_put(msg)
 
-    async def read(self) -> IMessage:
+    async def read(self) -> GenericIMessage:
         return await self.queue.coro_get()
 
     def empty(self):
