@@ -41,7 +41,7 @@ class AnyAppAccessPipline(Pipeline):
 
 @mark_pipelined(AnyAppPipeline)
 class AnyService(Service):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, name: str, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.q = "asgajsdhbngaksngkp;amsg"
 
@@ -92,7 +92,7 @@ async def main():
     ]
     acc.add_default_routes(map, AnyAppAccessPipline)
     app.add_service(acc)
-    app.add_service(AnyService())
+    app.add_service(AnyService("asfasf"))
     app.add_service(OverrideUserAccess())
     # app.add_service(acc)
 
