@@ -7,9 +7,8 @@ from typing import List, Any, Dict, Callable, Type, TypeVar, Generic, ParamSpec,
 
 from pydantic import BaseModel as PdModel
 from sanic import __version__ as sanic_version, Request, json, text, HTTPResponse
-
 from web_foundation.kernel import class_of_method, NamedContext
-from web_foundation.workers.web.sanic_ext.structs import InputContext, ProtectIdentity, HTTPMethod
+from web_foundation.workers.web.sanic_ext.structs import InputContext, ProtectIdentity, HTTPMethod, DtoType
 from web_foundation.workers.web.utils import validate_dto
 
 try:
@@ -36,7 +35,7 @@ class RequestParser:
     def __init__(self,
                  dto_validation_fnc: Callable[..., PdModel],
                  extracted_attrs: List[str] = None,
-                 struct: PdModel = None):
+                 struct: DtoType = None):
         self.dto_validation_fnc = dto_validation_fnc  # type: ignore
         self.struct = struct
         if extracted_attrs:
@@ -46,8 +45,9 @@ class RequestParser:
         self.extracted_attrs = extracted_attrs
 
     def income_(self, request: Request, **kwargs) -> InputContext:
-        incoming_context = InputContext(r_args=SimpleNamespace(), r_kwargs={}, named_ctx=request.app.ctx.named_ctx,
-                                        dto=None, channel=request.app.ctx.channel, request=request)
+        incoming_context = InputContext[self.struct](r_args=SimpleNamespace(), r_kwargs={},
+                                                     named_ctx=request.app.ctx.named_ctx,
+                                                     dto=None, channel=request.app.ctx.channel, request=request)
         if self.extracted_attrs:
             for attr in self.extracted_attrs:
                 setattr(incoming_context.r_args, attr, getattr(request, attr))
@@ -77,14 +77,17 @@ class ResponseConstructor:
             return self.default_response
 
 
-class Protector:
+ProtectService = TypeVar("ProtectService", bound=object)
+
+
+class Protector(Generic[ProtectService]):
     named_ctx: NamedContext
 
     def __init__(self, named_ctx: NamedContext):
         self.named_ctx = named_ctx
 
     @classmethod
-    async def protect(cls, request: Request) -> ProtectIdentity | None:
+    async def protect(cls, context: InputContext, cls_self: ProtectService) -> ProtectIdentity | None:
         return None
 
 
@@ -163,8 +166,8 @@ def set_to_pipline(uri: str,
         async def f(*args, **kwargs):
             req: Request = args[0]
             n_ctx = req.app.ctx.named_ctx
-            prot_identity = await (protector(n_ctx).protect(req))
             incoming = RequestParser(dto_validation_fnc, extracted_attrs, struct).income_(req, **kwargs)
+            prot_identity = await (protector(n_ctx).protect(incoming, class_of_method(target)))
             ret_val = await target(n_ctx.get_obj(class_of_method(target)), incoming, prot_identity)
             return ResponseConstructor(out_struct, return_fabric, default_response).return_(ret_val)
 
