@@ -1,11 +1,12 @@
+from __future__ import annotations
+
 from dataclasses import dataclass, field
 from enum import Enum
 from types import SimpleNamespace
-from typing import Dict
+from typing import Dict, TypeVar, Generic, Set
 
 from pydantic import BaseModel as PdModel
 from sanic import Request
-
 from web_foundation.kernel import NamedContext
 from web_foundation.kernel.isolates.channel import IChannel
 
@@ -15,13 +16,16 @@ class ProtectIdentity:
     pass
 
 
+DtoType = TypeVar("DtoType", bound=PdModel)
+
+
 @dataclass
-class InputContext:
+class InputContext(Generic[DtoType]):
     r_args: SimpleNamespace
     r_kwargs: Dict
     named_ctx: NamedContext
     channel: IChannel
-    dto: PdModel | None
+    dto: DtoType | None
     request: Request
 
 
@@ -33,5 +37,5 @@ class HTTPMethod(Enum):
     DELETE = "DELETE"
 
     @staticmethod
-    def all():
-        return [HTTPMethod.GET, HTTPMethod.POST, HTTPMethod.PATCH, HTTPMethod.DELETE]
+    def all() -> Set[HTTPMethod]:
+        return {HTTPMethod.GET, HTTPMethod.POST, HTTPMethod.PATCH, HTTPMethod.DELETE}
